componenttools.partition_components_cyclically_by_prolated_durations_exactly_with_overhang
==========================================================================================

.. autofunction:: abjad.tools.componenttools.partition_components_cyclically_by_prolated_durations_exactly_with_overhang
